<?php
/*
Plugin Name: ETWP Scrollbar (EasyToolsWP)
Description: A simple plugin to change the colors, sizes, border-radius, and background color of the scrollbar, as well as the option to hide the scrollbar.
Version: 1.1.2
Author: EasyToolsWP
*/

function etwp_add_admin_menu() { 
    add_submenu_page(
        'options-general.php',
        'ETWP Scrollbar',
        'ETWP Scrollbar',
        'manage_options',
        'etwp-scrollbar',
        'etwp_options_page'
    );
}
add_action('admin_menu', 'etwp_add_admin_menu');

function etwp_options_page() { 
    ?>
    <div class="wrap">
        <h1>ETWP Scrollbar Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('etwp_options_group');
            do_settings_sections('etwp-scrollbar');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

function etwp_settings_init() { 
    register_setting('etwp_options_group', 'etwp_options');

    add_settings_section('etwp_section', '', null, 'etwp-scrollbar');

    add_settings_field('etwp_color', 'Scrollbar Color', 'etwp_color_render', 'etwp-scrollbar', 'etwp_section');
    add_settings_field('etwp_width', 'Scrollbar Width (px)', 'etwp_width_render', 'etwp-scrollbar', 'etwp_section');
    add_settings_field('etwp_bg_color', 'Scrollbar Background Color', 'etwp_bg_color_render', 'etwp-scrollbar', 'etwp_section');
    add_settings_field('etwp_border_radius', 'Scrollbar Border Radius (px)', 'etwp_border_radius_render', 'etwp-scrollbar', 'etwp_section');
    add_settings_field('etwp_hide', 'Hide Scrollbar', 'etwp_hide_render', 'etwp-scrollbar', 'etwp_section');
}
add_action('admin_init', 'etwp_settings_init');

function etwp_color_render() { 
    $options = get_option('etwp_options');
    ?>
    <input type='text' name='etwp_options[etwp_color]' value='<?php echo isset($options['etwp_color']) ? esc_attr($options['etwp_color']) : '#000'; ?>'>
    <?php
}

function etwp_width_render() { 
    $options = get_option('etwp_options');
    ?>
    <input type='number' name='etwp_options[etwp_width]' value='<?php echo isset($options['etwp_width']) ? esc_attr($options['etwp_width']) : '10'; ?>'>
    <?php
}

function etwp_bg_color_render() { 
    $options = get_option('etwp_options');
    ?>
    <input type='text' name='etwp_options[etwp_bg_color]' value='<?php echo isset($options['etwp_bg_color']) ? esc_attr($options['etwp_bg_color']) : '#f1f1f1'; ?>'>
    <?php
}

function etwp_border_radius_render() { 
    $options = get_option('etwp_options');
    ?>
    <input type='number' name='etwp_options[etwp_border_radius]' value='<?php echo isset($options['etwp_border_radius']) ? esc_attr($options['etwp_border_radius']) : '0'; ?>'>
    <?php
}

function etwp_hide_render() { 
    $options = get_option('etwp_options');
    ?>
    <input type='checkbox' name='etwp_options[etwp_hide]' <?php checked($options['etwp_hide'], 1); ?> value='1'>
    <?php
}

function etwp_apply_custom_styles() {
    $options = get_option('etwp_options');
    ?>
    <style>
        body::-webkit-scrollbar {
            width: <?php echo isset($options['etwp_width']) ? esc_attr($options['etwp_width']) : '10'; ?>px;
        }
        body::-webkit-scrollbar-thumb {
            background-color: <?php echo isset($options['etwp_color']) ? esc_attr($options['etwp_color']) : '#000'; ?>;
            border-radius: <?php echo isset($options['etwp_border_radius']) ? esc_attr($options['etwp_border_radius']) : '0'; ?>px;
        }
        body::-webkit-scrollbar-track {
            background-color: <?php echo isset($options['etwp_bg_color']) ? esc_attr($options['etwp_bg_color']) : '#f1f1f1'; ?>;
        }
        <?php if (isset($options['etwp_hide']) && $options['etwp_hide'] == 1) : ?>
            body::-webkit-scrollbar {
                display: none;
            }
        <?php endif; ?>
    </style>
    <?php
}
add_action('wp_head', 'etwp_apply_custom_styles');
